@@ -1,6 +1,6 @@
+from django.conf import settings
 from django.contrib.auth.middleware import AuthenticationMiddleware
-from django.contrib.auth import login
-from garpix_keycloak.services import KeycloakService
+from django.contrib.auth import login, authenticate
 
 
 class KeycloakAuthMiddleware(AuthenticationMiddleware):
@@ -11,7 +11,6 @@ class KeycloakAuthMiddleware(AuthenticationMiddleware):
         if not request.user.is_authenticated and 'keycloak_state' in request.session and 'state' in request_data and 'code' in request_data and request_data.get(
                 'state') == request.session['keycloak_state']:
 
-            user = KeycloakService().get_user_from_request(request)
-
+            user = authenticate(request)
             if user:
                 login(request, user)
